@@ -4,6 +4,16 @@ from subprocess import call, PIPE
 from django.conf import settings as djangosettings
 
 
+def _is_installed(cmd):
+    there_is = False
+    cmd = [cmd, '--version']
+    try:
+        call(cmd, stdout=PIPE)
+        there_is = True
+    except OSError as e:
+        pass
+    return there_is
+
 
 class Settings():
     conf = djangosettings
@@ -22,18 +32,19 @@ class Settings():
                        'requirements.txt')
 
     @property
-    def LINT_CMD(self):
-        return getattr(self.conf, 'DJANGOMASTER_LINT_CMD', 'pep8')
+    def PYLINT_CMD(self):
+        return getattr(self.conf, 'DJANGOMASTER_PYLINT_CMD', 'pep8')
 
     @property
-    def LINT_IS_INSTALLED(self):
-        there_is = False
-        cmd = [self.LINT_CMD, '--version']
-        try:
-            call(cmd, stdout=PIPE)
-            there_is = True
-        except OSError as e:
-            pass
-        return there_is
+    def PYLINT_IS_INSTALLED(self):
+        return _is_installed(self.PYLINT_CMD)
+
+    @property
+    def JSLINT_CMD(self):
+        return getattr(self.conf, 'DJANGOMASTER_JSLINT_CMD', 'jshint')
+
+    @property
+    def JSLINT_IS_INSTALLED(self):
+        return _is_installed(self.JSLINT_CMD)
 
 settings = Settings()
