@@ -3,7 +3,7 @@ from django.conf.urls import patterns, url, include
 from djangomaster.views.home import HomeView
 from djangomaster.views.routes import RoutesListView
 from djangomaster.views.settings import SettingsListView
-from djangomaster.views.lint import LintView
+from djangomaster.views.lint import PyLintView, JsLintView
 
 
 urlpatterns = patterns(r'',
@@ -11,7 +11,8 @@ urlpatterns = patterns(r'',
     url(r'^$', HomeView.as_view(), name='home'),
     url(r'^routes/$', RoutesListView.as_view(), name='routes'),
     url(r'^settings/$', SettingsListView.as_view(), name='settings'),
-    url(r'^lint/$', LintView.as_view(), name='lint'),
+    url(r'^pylint/$', PyLintView.as_view(), name='pylint'),
+    url(r'^jslint/$', JsLintView.as_view(), name='jslint'),
 
 )
 
