@@ -1,8 +1,7 @@
 from django.conf import settings
 from django.core.urlresolvers import reverse, NoReverseMatch
-from django.views.generic import ListView
 
-from djangomaster.views import MasterMixin
+from djangomaster.views import MasterView
 
 
 
@@ -76,7 +75,7 @@ class Route(object):
             return ''
 
 
-class RoutesListView(MasterMixin, ListView):
+class RoutesListView(MasterView):
     template_name = 'djangomaster/routes.html'
     context_object_name = 'route_list'
     menu_item = 'routes'
